@@ -7,7 +7,7 @@ require_once 'Horde/Identity.php';
  * Horde Kronolith driver for the Kolab IMAP Server.
  * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
- * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.30 2009-01-06 15:24:45 jan Exp $
+ * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.32 2010/09/23 17:59:12 wrobel Exp $
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -178,7 +178,7 @@ class Kronolith_Driver_kolab extends Kronolith_Driver {
 /**
  * Horde Kronolith wrapper to distinguish between both Kolab driver implementations.
  *
- * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.30 2009-01-06 15:24:45 jan Exp $
+ * $Horde: kronolith/lib/Driver/kolab.php,v 1.16.2.32 2010/09/23 17:59:12 wrobel Exp $
  *
  * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
@@ -1124,12 +1124,18 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
             return $result;
         }
 
-        if (is_null($startDate)) {
+        if (empty($startDate)) {
             $startDate = &new Horde_Date(array('mday' => 1, 'month' => 1, 'year' => 0000));
         }
-        if (is_null($endDate)) {
+        if (empty($endDate)) {
             $endDate = &new Horde_Date(array('mday' => 31, 'month' => 12, 'year' => 9999));
         }
+        if (!is_a($startDate, 'Horde_Date')) {
+            $startDate = &new Horde_Date($startDate);
+        }
+        if (!is_a($endDate, 'Horde_Date')) {
+            $endDate = &new Horde_Date($endDate);
+        }
 
         $ids = array();
 
@@ -1305,7 +1311,7 @@ class Kronolith_Driver_kolab_wrapper_new extends Kronolith_Driver_kolab_wrapper
 
         global $kronolith_shares;
         $target = &$kronolith_shares->getShare($newCalendar);
-        $folder = $target->get('folder');
+        $folder = $target->getId();
 
         $result = $this->_store->move($eventId, $folder);
         if ($result) {
